package acceptance

import (
	"io/ioutil"
	"net/http"
	"path"
	"strings"
	"testing"

	"github.com/stretchr/testify/require"
	"gitlab.com/gitlab-org/gitlab-metrics-exporter/internal/testhelpers"
)

const (
	testServerAddress = "localhost:8082"
)

func Test_Acceptance_GetMetrics(t *testing.T) {
	tests := []struct {
		client   *http.Client
		endpoint string
		flags    []string
	}{
		{testhelpers.HttpClient(t), "http://" + testServerAddress, []string{"-p", "self"}},
		{testhelpers.HttpsClient(t), "https://" + testServerAddress, []string{
			"-p", "self",
			"--cert-file", path.Join(testhelpers.CertsDir, "cert.pem"),
			"--cert-key", path.Join(testhelpers.CertsDir, "key.pem"),
		}},
	}

	for _, tc := range tests {
		server, err := testhelpers.StartServer(tc.flags...)
		require.NoError(t, err)

		func() {
			defer server.Stop()

			require.NoError(t, testhelpers.Await(func() bool {
				resp, _ := tc.client.Get(tc.endpoint)
				return resp != nil
			}))

			resp, err := tc.client.Get(tc.endpoint + "/metrics")
			require.NoError(t, err)
			defer resp.Body.Close()
			require.Equal(t, 200, resp.StatusCode)

			bytes, err := ioutil.ReadAll(resp.Body)
			require.NoError(t, err)
			require.NotEmpty(t, bytes)
			require.True(t, strings.HasPrefix(string(bytes), "# HELP"))
		}()
	}
}
